@@ -36,26 +36,29 @@
 #include "dh-enum-types.h"
 #include "dh-settings.h"
 #include "eggfindbar.h"
+#include "gedit-close-button.h"
 
 #define TAB_WIDTH_N_CHARS 15
 
-struct _DhWindowPriv {
-        GtkWidget      *main_box;
+typedef struct {
         GtkWidget      *hpaned;
         GtkWidget      *sidebar;
         GtkWidget      *notebook;
         GtkWidget      *header_bar;
-
-        GtkWidget      *vbox;
+        GtkWidget      *back_button;
+        GtkImage       *back_button_image;
+        GtkWidget      *forward_button;
+        GtkImage       *forward_button_image;
+        GtkWidget      *close_button;
+        GtkWidget      *grid_sidebar;
+        GtkWidget      *grid_documents;
         GtkWidget      *findbar;
 
-        GtkBuilder     *builder;
-
         DhLink         *selected_search_link;
         guint           find_source_id;
         DhSettings     *settings;
         guint           fonts_changed_id;
-};
+} DhWindowPrivate;
 
 enum {
         OPEN_LINK,
@@ -139,10 +142,7 @@ static void           window_close_tab               (DhWindow *window,
                                                       gint      page_num);
 static gboolean       do_search                      (DhWindow *window);
 
-G_DEFINE_TYPE (DhWindow, dh_window, GTK_TYPE_APPLICATION_WINDOW);
-
-#define GET_PRIVATE(instance) G_TYPE_INSTANCE_GET_PRIVATE \
-  (instance, DH_TYPE_WINDOW, DhWindowPriv);
+G_DEFINE_TYPE_WITH_PRIVATE (DhWindow, dh_window, GTK_TYPE_APPLICATION_WINDOW);
 
 static void
 new_tab_cb (GSimpleAction *action,
@@ -172,10 +172,10 @@ static void
 window_close_tab (DhWindow *window,
                   gint      page_num)
 {
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
         gint          pages;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         gtk_notebook_remove_page (GTK_NOTEBOOK (priv->notebook), page_num);
 
@@ -195,9 +195,12 @@ close_cb (GSimpleAction *action,
           gpointer       user_data)
 {
         DhWindow *window = user_data;
+        DhWindowPrivate *priv;
         gint page_num;
 
-        page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (window->priv->notebook));
+        priv = dh_window_get_instance_private (window);
+
+        page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook));
         window_close_tab (window, page_num);
 }
 
@@ -208,9 +211,9 @@ copy_cb (GSimpleAction *action,
 {
         DhWindow *window = user_data;
         GtkWidget *widget;
-        DhWindowPriv  *priv;
+        DhWindowPrivate *priv;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         widget = gtk_window_get_focus (GTK_WINDOW (window));
 
@@ -237,9 +240,9 @@ find_cb (GSimpleAction *action,
          gpointer       user_data)
 {
         DhWindow *window = user_data;
-        DhWindowPriv  *priv;
+        DhWindowPrivate *priv;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         gtk_widget_show (priv->findbar);
         gtk_widget_grab_focus (priv->findbar);
@@ -370,8 +373,11 @@ focus_search_cb (GSimpleAction *action,
                  gpointer       user_data)
 {
         DhWindow *window = user_data;
+        DhWindowPrivate *priv;
 
-        dh_sidebar_set_search_focus (DH_SIDEBAR (window->priv->sidebar));
+        priv = dh_window_get_instance_private (window);
+
+        dh_sidebar_set_search_focus (DH_SIDEBAR (priv->sidebar));
 }
 
 static void
@@ -380,11 +386,11 @@ go_back_cb (GSimpleAction *action,
             gpointer       user_data)
 {
         DhWindow      *window = user_data;
-        DhWindowPriv  *priv;
+        DhWindowPrivate *priv;
         WebKitWebView *web_view;
         GtkWidget     *frame;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         frame = gtk_notebook_get_nth_page (
                 GTK_NOTEBOOK (priv->notebook),
@@ -400,11 +406,11 @@ go_forward_cb (GSimpleAction *action,
                gpointer       user_data)
 {
         DhWindow      *window = user_data;
-        DhWindowPriv  *priv;
+        DhWindowPrivate *priv;
         WebKitWebView *web_view;
         GtkWidget     *frame;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         frame = gtk_notebook_get_nth_page (GTK_NOTEBOOK (priv->notebook),
                                            gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook)));
@@ -469,9 +475,12 @@ settings_fonts_changed_cb (DhSettings *settings,
                            gpointer user_data)
 {
         DhWindow *window = DH_WINDOW (user_data);
-        DhWindowPriv *priv = window->priv;
+        DhWindowPrivate *priv;
         gint i;
         WebKitWebView *view;
+
+        priv = dh_window_get_instance_private (window);
+
         /* change font for all pages */
         for (i = 0; i < gtk_notebook_get_n_pages (GTK_NOTEBOOK(priv->notebook)); i++) {
                 GtkWidget *page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (priv->notebook), i);
@@ -486,10 +495,11 @@ window_configure_event_cb (GtkWidget *window,
                            gpointer user_data)
 {
         DhWindow *dhwindow;
-        DhWindowPriv  *priv;
+        DhWindowPrivate  *priv;
 
         dhwindow = DH_WINDOW (user_data);
-        priv = GET_PRIVATE (dhwindow);
+        priv = dh_window_get_instance_private (dhwindow);
+
         dh_util_window_settings_save (
                 GTK_WINDOW (window),
                 dh_settings_peek_window_settings (priv->settings), TRUE);
@@ -499,17 +509,14 @@ window_configure_event_cb (GtkWidget *window,
 static void
 dh_window_init (DhWindow *window)
 {
-        DhWindowPriv  *priv;
+        DhWindowPrivate  *priv;
         GtkAccelGroup *accel_group;
         GClosure      *closure;
         gint           i;
-        GError        *error = NULL;
 
-        priv = GET_PRIVATE (window);
-        window->priv = priv;
-
-        gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (window), TRUE);
+        gtk_widget_init_template (GTK_WIDGET (window));
 
+        priv = dh_window_get_instance_private (window);
         priv->selected_search_link = NULL;
 
         /* handle settings */
@@ -519,18 +526,6 @@ dh_window_init (DhWindow *window)
                                                    G_CALLBACK (settings_fonts_changed_cb),
                                                    window);
 
-        /* Setup builder */
-        priv->builder = gtk_builder_new ();
-        if (!gtk_builder_add_from_resource (priv->builder, "/org/gnome/devhelp/devhelp.ui", &error)) {
-                g_error ("Cannot add resource to builder: %s", error ? error->message : "unknown error");
-                g_clear_error (&error);
-        }
-
-        priv->main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-        gtk_widget_show (priv->main_box);
-
-        gtk_container_add (GTK_CONTAINER (window), priv->main_box);
-
         g_signal_connect (window,
                           "open-link",
                           G_CALLBACK (window_open_link_cb),
@@ -555,18 +550,20 @@ dh_window_init (DhWindow *window)
 }
 
 static void
-dispose (GObject *object)
+dh_window_dispose (GObject *object)
 {
-	DhWindow *self = DH_WINDOW (object);
+        DhWindow *window = DH_WINDOW (object);
+        DhWindowPrivate *priv;
 
-        if (self->priv->fonts_changed_id) {
-                if (self->priv->settings && g_signal_handler_is_connected (self->priv->settings, self->priv->fonts_changed_id))
-                        g_signal_handler_disconnect (self->priv->settings, self->priv->fonts_changed_id);
-                self->priv->fonts_changed_id = 0;
+        priv = dh_window_get_instance_private (window);
+
+        if (priv->fonts_changed_id) {
+                if (priv->settings && g_signal_handler_is_connected (priv->settings, priv->fonts_changed_id))
+                        g_signal_handler_disconnect (priv->settings, priv->fonts_changed_id);
+                priv->fonts_changed_id = 0;
         }
 
-        g_clear_object (&self->priv->settings);
-        g_clear_object (&self->priv->builder);
+        g_clear_object (&priv->settings);
 
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (dh_window_parent_class)->dispose (object);
@@ -576,8 +573,9 @@ static void
 dh_window_class_init (DhWindowClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
-        g_type_class_add_private (klass, sizeof (DhWindowPriv));
-        object_class->dispose = dispose;
+        GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+
+        object_class->dispose = dh_window_dispose;
 
         signals[OPEN_LINK] =
                 g_signal_new ("open-link",
@@ -591,15 +589,19 @@ dh_window_class_init (DhWindowClass *klass)
                               G_TYPE_STRING,
                               DH_TYPE_OPEN_LINK_FLAGS);
 
-        gtk_rc_parse_string ("style \"devhelp-tab-close-button-style\"\n"
-                             "{\n"
-                             "GtkWidget::focus-padding = 0\n"
-                             "GtkWidget::focus-line-width = 0\n"
-                             "xthickness = 0\n"
-                             "ythickness = 0\n"
-                             "}\n"
-                             "widget \"*.devhelp-tab-close-button\" "
-                             "style \"devhelp-tab-close-button-style\"");
+        /* Bind class to template */
+        gtk_widget_class_set_template_from_resource (widget_class,
+                                                     "/org/gnome/devhelp/dh-window.ui");
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, header_bar);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, back_button);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, back_button_image);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, forward_button);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, forward_button_image);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, close_button);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, hpaned);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, grid_sidebar);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, grid_documents);
+        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, notebook);
 }
 
 static void
@@ -608,10 +610,10 @@ window_web_view_switch_page_cb (GtkNotebook     *notebook,
                                 guint            new_page_num,
                                 DhWindow        *window)
 {
-        DhWindowPriv *priv;
-        GtkWidget    *new_page;
+        DhWindowPrivate *priv;
+        GtkWidget *new_page;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         new_page = gtk_notebook_get_nth_page (notebook, new_page_num);
         if (new_page) {
@@ -649,23 +651,13 @@ window_web_view_switch_page_after_cb (GtkNotebook     *notebook,
 static void
 window_populate (DhWindow *window)
 {
-        DhWindowPriv  *priv;
+        DhWindowPrivate *priv;
         DhBookManager *book_manager;
-        GtkWidget     *back_button;
-        GtkWidget     *back_image;
-        GtkWidget     *forward_button;
-        GtkWidget     *forward_image;
-        GtkWidget     *box;
-        GtkWidget     *menu_button;
-        GtkWidget     *menu_image;
-        GObject       *menu;
         const char *prev_icon, *next_icon;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
         book_manager = dh_app_peek_book_manager (DH_APP (gtk_window_get_application (GTK_WINDOW (window))));
 
-        priv->header_bar = gtk_header_bar_new ();
-
         if (gtk_widget_get_direction (GTK_WIDGET (window)) == GTK_TEXT_DIR_RTL) {
                 prev_icon = "go-previous-rtl-symbolic";
                 next_icon = "go-next-rtl-symbolic";
@@ -674,69 +666,24 @@ window_populate (DhWindow *window)
                 next_icon = "go-next-symbolic";
         }
 
-        back_button = gtk_button_new ();
-        back_image = gtk_image_new_from_icon_name (prev_icon, GTK_ICON_SIZE_MENU);
-        gtk_button_set_image (GTK_BUTTON (back_button), back_image);
-        gtk_widget_set_tooltip_text (back_button, _("Back"));
-        gtk_actionable_set_action_name (GTK_ACTIONABLE (back_button), "win.go-back");
-        gtk_widget_set_valign (back_button, GTK_ALIGN_CENTER);
-        gtk_style_context_add_class (gtk_widget_get_style_context (back_button),
-				     "image-button");
+        gtk_image_set_from_icon_name (priv->back_button_image, prev_icon, GTK_ICON_SIZE_MENU);
+        gtk_image_set_from_icon_name (priv->forward_button_image, next_icon, GTK_ICON_SIZE_MENU);
 
-        forward_button = gtk_button_new ();
-        forward_image = gtk_image_new_from_icon_name (next_icon, GTK_ICON_SIZE_MENU);
-        gtk_button_set_image (GTK_BUTTON (forward_button), forward_image);
-        gtk_widget_set_tooltip_text (forward_button, _("Forward"));
-        gtk_actionable_set_action_name (GTK_ACTIONABLE (forward_button), "win.go-forward");
-        gtk_widget_set_valign (forward_button, GTK_ALIGN_CENTER);
-        gtk_style_context_add_class (gtk_widget_get_style_context (forward_button),
-				     "image-button");
-
-        box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-        gtk_style_context_add_class (gtk_widget_get_style_context (box), "linked");
-        gtk_box_pack_start (GTK_BOX (box), back_button, FALSE, FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (box), forward_button, FALSE, FALSE, 0);
-        gtk_header_bar_pack_start (GTK_HEADER_BAR (priv->header_bar), box);
-
-        menu_button = gtk_menu_button_new ();
-        menu_image = gtk_image_new_from_icon_name ("emblem-system-symbolic", GTK_ICON_SIZE_MENU);
-        gtk_button_set_image (GTK_BUTTON (menu_button), menu_image);
-        gtk_actionable_set_action_name (GTK_ACTIONABLE (menu_button), "win.gear-menu");
-        gtk_widget_set_valign (menu_button, GTK_ALIGN_CENTER);
-        gtk_style_context_add_class (gtk_widget_get_style_context (menu_button),
-				     "image-button");
-
-        gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->header_bar), menu_button);
-
-        menu = gtk_builder_get_object (priv->builder, "window-menu");
-        gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (menu_button), G_MENU_MODEL (menu));
-
-        /* Add toolbar to main box */
-        gtk_box_pack_start (GTK_BOX (priv->main_box), priv->header_bar,
-                            FALSE, FALSE, 0);
-
-        priv->hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
-        gtk_box_pack_start (GTK_BOX (priv->main_box), priv->hpaned, TRUE, TRUE, 0);
+        g_signal_connect_swapped (priv->close_button, "clicked",
+                                  G_CALLBACK (gtk_window_close), window);
 
         /* Sidebar */
         priv->sidebar = dh_sidebar_new (book_manager);
-        gtk_paned_add1 (GTK_PANED (priv->hpaned), priv->sidebar);
+        gtk_widget_set_vexpand (priv->sidebar, TRUE);
+        gtk_widget_set_hexpand (priv->sidebar, TRUE);
+        gtk_widget_show (priv->sidebar);
+        gtk_container_add (GTK_CONTAINER (priv->grid_sidebar), priv->sidebar);
         g_signal_connect (priv->sidebar,
                           "link-selected",
                           G_CALLBACK (window_search_link_selected_cb),
                           window);
 
-        /* Document view */
-        priv->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-        gtk_paned_add2 (GTK_PANED (priv->hpaned), priv->vbox);
-
         /* HTML tabs notebook. */
-        priv->notebook = gtk_notebook_new ();
-        gtk_container_set_border_width (GTK_CONTAINER (priv->notebook), 0);
-        gtk_notebook_set_show_border (GTK_NOTEBOOK (priv->notebook), FALSE);
-        gtk_notebook_set_scrollable (GTK_NOTEBOOK (priv->notebook), TRUE);
-        gtk_box_pack_start (GTK_BOX (priv->vbox), priv->notebook, TRUE, TRUE, 0);
-
         g_signal_connect (priv->notebook,
                           "switch-page",
                           G_CALLBACK (window_web_view_switch_page_cb),
@@ -749,7 +696,7 @@ window_populate (DhWindow *window)
         /* Create findbar */
         priv->findbar = egg_find_bar_new ();
         gtk_widget_set_no_show_all (priv->findbar, TRUE);
-        gtk_box_pack_start (GTK_BOX (priv->vbox), priv->findbar, FALSE, FALSE, 0);
+        gtk_container_add (GTK_CONTAINER (priv->grid_documents), priv->findbar);
 
         g_signal_connect (priv->findbar,
                           "notify::search-string",
@@ -772,8 +719,6 @@ window_populate (DhWindow *window)
                           G_CALLBACK (window_findbar_close_cb),
                           window);
 
-        gtk_widget_show_all (priv->hpaned);
-
         /* Focus search in sidebar by default */
         dh_sidebar_set_search_focus (DH_SIDEBAR (priv->sidebar));
 
@@ -879,9 +824,9 @@ window_web_view_load_changed_cb (WebKitWebView   *web_view,
                                  DhWindow        *window)
 {
         const gchar *uri;
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         if (load_event != WEBKIT_LOAD_COMMITTED)
                 return;
@@ -934,12 +879,11 @@ window_search_link_selected_cb (GObject  *ignored,
                                 DhLink   *link,
                                 DhWindow *window)
 {
-        DhWindowPriv  *priv;
+        DhWindowPrivate  *priv;
         WebKitWebView *view;
         gchar         *uri;
 
-        priv = window->priv;
-
+        priv = dh_window_get_instance_private (window);
         priv->selected_search_link = link;
 
         view = window_get_active_web_view (window);
@@ -996,11 +940,13 @@ window_web_view_button_press_event_cb (WebKitWebView  *web_view,
 static gboolean
 do_search (DhWindow *window)
 {
-        DhWindowPriv         *priv = window->priv;
+        DhWindowPrivate *priv;
         WebKitFindController *find_controller;
         guint                 find_options = WEBKIT_FIND_OPTIONS_WRAP_AROUND;
         const gchar          *search_text;
 
+        priv = dh_window_get_instance_private (window);
+
         find_controller = webkit_web_view_get_find_controller (window_get_active_web_view (window));
         if (!egg_find_bar_get_case_sensitive (EGG_FIND_BAR (priv->findbar)))
                 find_options |= WEBKIT_FIND_OPTIONS_CASE_INSENSITIVE;
@@ -1018,7 +964,9 @@ window_find_search_changed_cb (GObject    *object,
                                GParamSpec *pspec,
                                DhWindow   *window)
 {
-        DhWindowPriv *priv = window->priv;
+        DhWindowPrivate *priv;
+
+        priv = dh_window_get_instance_private (window);
 
         if (priv->find_source_id != 0) {
                 g_source_remove (priv->find_source_id);
@@ -1039,10 +987,12 @@ window_find_case_changed_cb (GObject    *object,
 static void
 findbar_find_next (DhWindow *window)
 {
-        DhWindowPriv         *priv = window->priv;
+        DhWindowPrivate *priv;
         WebKitWebView        *view;
         WebKitFindController *find_controller;
 
+        priv = dh_window_get_instance_private (window);
+
         view = window_get_active_web_view (window);
 
         gtk_widget_show (priv->findbar);
@@ -1061,10 +1011,12 @@ window_find_next_cb (GtkWidget *widget,
 static void
 findbar_find_previous (DhWindow *window)
 {
-        DhWindowPriv         *priv = window->priv;
+        DhWindowPrivate *priv;
         WebKitWebView        *view;
         WebKitFindController *find_controller;
 
+        priv = dh_window_get_instance_private (window);
+
         view = window_get_active_web_view (window);
 
         gtk_widget_show (priv->findbar);
@@ -1084,10 +1036,12 @@ static void
 window_findbar_close_cb (GtkWidget *widget,
                          DhWindow  *window)
 {
-        DhWindowPriv         *priv = window->priv;
+        DhWindowPrivate *priv;
         WebKitWebView        *view;
         WebKitFindController *find_controller;
 
+        priv = dh_window_get_instance_private (window);
+
         view = window_get_active_web_view (window);
 
         gtk_widget_hide (priv->findbar);
@@ -1113,10 +1067,10 @@ window_web_view_tab_accel_cb (GtkAccelGroup   *accel_group,
                               GdkModifierType  mod,
                               DhWindow        *window)
 {
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
         gint          i, num;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         num = -1;
         for (i = 0; i < G_N_ELEMENTS (tab_accel_keys); i++) {
@@ -1137,7 +1091,7 @@ window_open_new_tab (DhWindow    *window,
                      const gchar *location,
                      gboolean     switch_focus)
 {
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
         GtkWidget    *view;
         GtkWidget    *vbox;
         GtkWidget    *label;
@@ -1146,7 +1100,7 @@ window_open_new_tab (DhWindow    *window,
         gchar *font_fixed = NULL;
         gchar *font_variable = NULL;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         /* Prepare the web view */
         view = webkit_web_view_new ();
@@ -1240,14 +1194,17 @@ static void
 close_button_clicked_cb (GtkButton *button,
                          DhWindow  *window)
 {
+        DhWindowPrivate *priv;
         GtkWidget *parent_tab;
         gint       pages;
         gint       i;
 
+        priv = dh_window_get_instance_private (window);
+
         parent_tab = g_object_get_data (G_OBJECT (button), "parent_tab");
-        pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (window->priv->notebook));
+        pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (priv->notebook));
         for (i=0; i<pages; i++) {
-                if (gtk_notebook_get_nth_page (GTK_NOTEBOOK (window->priv->notebook), i) == parent_tab) {
+                if (gtk_notebook_get_nth_page (GTK_NOTEBOOK (priv->notebook), i) == parent_tab) {
                         window_close_tab (window, i);
                         break;
                 }
@@ -1262,7 +1219,6 @@ window_new_tab_label (DhWindow        *window,
         GtkWidget *label;
         GtkWidget *hbox;
         GtkWidget *close_button;
-        GtkWidget *image;
 
         hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
 
@@ -1271,17 +1227,12 @@ window_new_tab_label (DhWindow        *window,
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
         gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
-        close_button = gtk_button_new ();
-        gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
-        gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
-        gtk_widget_set_name (close_button, "devhelp-tab-close-button");
+        close_button = gedit_close_button_new ();
         g_object_set_data (G_OBJECT (close_button), "parent_tab", (gpointer) parent);
 
-        image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
         g_signal_connect (close_button, "clicked",
                           G_CALLBACK (close_button_clicked_cb),
                           window);
-        gtk_container_add (GTK_CONTAINER (close_button), image);
 
         gtk_box_pack_start (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
 
@@ -1294,11 +1245,11 @@ window_new_tab_label (DhWindow        *window,
 static WebKitWebView *
 window_get_active_web_view (DhWindow *window)
 {
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
         gint          page_num;
         GtkWidget    *page;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook));
         if (page_num == -1) {
@@ -1313,11 +1264,11 @@ window_get_active_web_view (DhWindow *window)
 static GtkWidget *
 window_get_active_info_bar (DhWindow *window)
 {
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
         gint          page_num;
         GtkWidget    *page;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook));
         if (page_num == -1) {
@@ -1334,9 +1285,9 @@ window_update_title (DhWindow      *window,
                      WebKitWebView *web_view,
                      const gchar   *web_view_title)
 {
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         if (!web_view_title)
                 web_view_title = webkit_web_view_get_title (web_view);
@@ -1354,14 +1305,14 @@ window_tab_set_title (DhWindow      *window,
                       WebKitWebView *web_view,
                       const gchar   *title)
 {
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
         gint          num_pages, i;
         GtkWidget    *page;
         GtkWidget    *hbox;
         GtkWidget    *label;
         GtkWidget    *page_web_view;
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         if (!title || title[0] == '\0') {
                 title = _("Empty Page");
@@ -1391,17 +1342,13 @@ GtkWidget *
 dh_window_new (DhApp *application)
 {
         DhWindow     *window;
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
 
-        window = g_object_new (DH_TYPE_WINDOW, NULL);
-        priv = window->priv;
-
-        gtk_window_set_application (GTK_WINDOW (window), GTK_APPLICATION (application));
+        window = g_object_new (DH_TYPE_WINDOW, "application", application, NULL);
+        priv = dh_window_get_instance_private (window);
 
         window_populate (window);
 
-        gtk_window_set_icon_name (GTK_WINDOW (window), "devhelp");
-
         g_signal_connect (window, "configure-event",
                           G_CALLBACK (window_configure_event_cb),
                           window);
@@ -1421,11 +1368,11 @@ void
 dh_window_search (DhWindow    *window,
                   const gchar *str)
 {
-        DhWindowPriv *priv;
+        DhWindowPrivate *priv;
 
         g_return_if_fail (DH_IS_WINDOW (window));
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         dh_sidebar_set_search_string (DH_SIDEBAR (priv->sidebar), str);
 }
@@ -1435,13 +1382,13 @@ void
 _dh_window_display_uri (DhWindow    *window,
                         const gchar *uri)
 {
-        DhWindowPriv  *priv;
+        DhWindowPrivate  *priv;
         WebKitWebView *web_view;
 
         g_return_if_fail (DH_IS_WINDOW (window));
         g_return_if_fail (uri != NULL);
 
-        priv = window->priv;
+        priv = dh_window_get_instance_private (window);
 
         web_view = window_get_active_web_view (window);
         webkit_web_view_load_uri (web_view, uri);
